@@ -29,6 +29,12 @@ class ConfigFile(object):
         c = self._load_yaml()
         if not c:
             return
+
+        if not isinstance(c, dict):
+            raise TypeError(u'YAML file {} did not load as a dict.  Please '
+                            u'check its formatting.'.format(
+                                self.config_file_path))
+
         c = c.get(self.config['ENVIRONMENT'].upper(), c)
         for key, value in c.iteritems():
             if not key.isupper():
@@ -36,8 +42,13 @@ class ConfigFile(object):
                     '{} config key in {} must be uppercase.'.format(
                         key, self.filename)
                 )
-            if value in config_files_lookup.keys():
-                if value == self.keyword:
+            if isinstance(value, basestring) and value.startswith('ordbok'):
+                if value not in config_files_lookup.keys():
+                    raise Exception(
+                        '{0} is required to be specified in {1} '
+                        'but {1} was not registered with Ordbok'.format(
+                            key, self.config_file_path))
+                elif value == self.keyword:
                     raise Exception(
                         'Cannot require {} required Ordbok config '
                         'variables in their own file.'.format(
@@ -99,7 +110,7 @@ class Ordbok(dict):
                 '{}_ENVIRONMENT'.format(self.near_miss_key.upper()),
                 default_environment).lower()
 
-        if not getattr(self, 'root_path'):
+        if not getattr(self, 'root_path', None):
             self.root_path = os.getcwd()
 
         if not custom_config_files:
